Changelog
=========


0.1.5 (2023-08-15)
------------------

Fix
~~~
- Cli loading time. [Sebastian Krüger]

Changes
~~~~~~~
- Cleanup. [Sebastian Krüger]

Other
~~~~~
- README. [Sebastian Krüger]


0.1.4 (2023-08-14)
------------------

Fix
~~~
- More tests and minor bugs. [Sebastian Krüger]

Changes
~~~~~~~
- Publish workflow. [Sebastian Krüger]
- Use mock. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.3 (2023-08-14)
------------------

Fix
~~~
- Script name. [Sebastian Krüger]

Changes
~~~~~~~
- Add lint task. [Sebastian Krüger]
- Pygments theme. [Sebastian Krüger]
- Docs styling. [Sebastian Krüger]
- Styling docs theme. [Sebastian Krüger]
- Salmon primary color. [Sebastian Krüger]
- Theme colors. [Sebastian Krüger]
- Docs theme colors. [Sebastian Krüger]
- Changelog. [Sebastian Krüger]

Other
~~~~~
- CHANGELOG. [Sebastian Krüger]
- README. [Sebastian Krüger]


0.1.2 (2023-08-12)
------------------

Feature
~~~~~~~
- Better roop. [Sebastian Krüger]
- Image variations. [Sebastian Krüger]
- Lora scale. [Sebastian Krüger]
- Lora weights. [Sebastian Krüger]
- Compel style. [Sebastian Krüger]
- Compel and syntax for prompt. [Sebastian Krüger]
- Switch to safetensors. [Sebastian Krüger]
- Compel. [Sebastian Krüger]
- Add loras. [Sebastian Krüger]
- Conditioning scale. [Sebastian Krüger]
- Conditioning scale. [Sebastian Krüger]
- Controlnet. [Sebastian Krüger]
- Roop. [Sebastian Krüger]
- Autocomplete. [Sebastian Krüger]
- Txt2img. [Sebastian Krüger]
- Prompt generator. [Sebastian Krüger]
- Cli. [Sebastian Krüger]
- Advanced text generation. [Sebastian Krüger]
- Create model. [Sebastian Krüger]
- Notebooks (wip) [Sebastian Krüger]
- Switch to python. [Sebastian Krüger]
- Docs. [Sebastian Krüger]

Fix
~~~
- Roop. [Sebastian Krüger]
- Variations. [Sebastian Krüger]
- Image resize. [Sebastian Krüger]
- Roop. [Sebastian Krüger]
- Compel quoting. [Sebastian Krüger]
- Prompt context. [Sebastian Krüger]
- Variations. [Sebastian Krüger]
- Variations. [Sebastian Krüger]
- Variations. [Sebastian Krüger]
- Prompt. [Sebastian Krüger]
- Lora scale. [Sebastian Krüger]
- Prompt. [Sebastian Krüger]
- Prompt. [Sebastian Krüger]
- Images save. [Sebastian Krüger]
- Tensorflow version for colab. [Sebastian Krüger]
- Template command. [Sebastian Krüger]
- Ignore warnings. [Sebastian Krüger]
- File naming. [Sebastian Krüger]
- Torch config. [Sebastian Krüger]
- Controlnet generator. [Sebastian Krüger]
- Cuda optimization. [Sebastian Krüger]
- Diffusers device selection. [Sebastian Krüger]
- Torch device selection. [Sebastian Krüger]
- Requirements.txt. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Scripts. [Sebastian Krüger]
- Script for colab. [Sebastian Krüger]
- Load truncated images. [Sebastian Krüger]

Changes
~~~~~~~
- Manifest. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Rename to giger. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Docs. [Sebastian Krüger]
- Examples. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Colab requirements. [Sebastian Krüger]
- Fixing. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Reactive argscomplete. [Sebastian Krüger]
- Remove argcomplete. [Sebastian Krüger]
- Mac usage. [Sebastian Krüger]
- Readme. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]
- Rename to sd. [Sebastian Krüger]
- Remove demon. [Sebastian Krüger]
- Refactored for combined usage. [Sebastian Krüger]
- Switch to GPU. [Sebastian Krüger]
- Prompts. [Sebastian Krüger]
- Cleanup. [Sebastian Krüger]

Other
~~~~~
- Initial commit. [Sebastian Krüger]
